@@ -187,12 +187,12 @@ def temp_standard_scale(params):
 
 
 def temp_normalize(params):
+    columns = params['columns']
     parameters = {
-        "X" : params['column'], 
         "norm" : params['norm'], 
         "copy" : params['copy'],
     }
-    return f"data = huble.sklearn.normalize(data=data, parameters={parameters})"
+    return f"data = huble.sklearn.normalize(data=data, columns={columns}, parameters={parameters})"
 
 
 def temp_ordinal_encode(params):
